==> haskell-servant-0.20.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant
version:              0.20.2
visibility:           public
id:                   servant-0.20.2-5NR7diwHk6pKVXTL4oOysQ
key:                  servant-0.20.2-5NR7diwHk6pKVXTL4oOysQ
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  97b3b9e503e05b7d67f67befc30d4207
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.HttpVersion
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Status Servant.API.Stream
    Servant.API.Sub Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.UVerb Servant.API.UVerb.Union Servant.API.Vault
    Servant.API.Verbs Servant.API.WithNamedContext
    Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.2.8/site-local/servant-0.20.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/servant-0.20.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.2-5NR7diwHk6pKVXTL4oOysQ
depends:
    QuickCheck-2.14.3-4ByVFEBmTRSJjm02AG2pXb
    aeson-2.1.2.1-HbpdIbO6AMR9AnrzgnqgHA
    attoparsec-0.14.4-41Mp0Rehn85G1bRN4BaFh7 base-4.16.4.0
    bifunctors-5.6-3q20CRTob0hIbVQz1Tj462 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-JUM6fESZLXwGrFMGnpRYl
    constraints-0.13.4-F7y52sLTSVq3JKQcHgQVlb containers-0.6.5.1
    deepseq-1.4.6.1 http-api-data-0.5.1-JVe04Xa7BT2ABZIESqpX9P
    http-media-0.8.1.1-C5xsVofPYvLLKNnZaGLhk1
    http-types-0.12.4-IK3jZB6tw6k2KWf3RXsYsl
    mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi mtl-2.2.2
    network-uri-2.6.4.2-8ohwraftYBVA933qpHaQpI
    singleton-bool-0.1.7-1uubXFtCW7Z2sKJGUSh2pN
    sop-core-0.5.0.2-LphaeyqHso5CwMqI1CLIch text-1.2.5.0
    transformers-0.5.6.2 vault-0.3.1.5-DS3zPk3zcSFDY8IR1BK7wl

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.20.2-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant
version:              0.20.2
visibility:           public
id:                   servant-0.20.2-4Ebt9ZPlvdVmzNwIOxEBB
key:                  servant-0.20.2-4Ebt9ZPlvdVmzNwIOxEBB
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  67983f4096f0877e95a12202057aad69
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.HttpVersion
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Status Servant.API.Stream
    Servant.API.Sub Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.UVerb Servant.API.UVerb.Union Servant.API.Vault
    Servant.API.Verbs Servant.API.WithNamedContext
    Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.2.8/site-local/servant-0.20.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/servant-0.20.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.2-4Ebt9ZPlvdVmzNwIOxEBB
depends:
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-GayFRV4oUv8L6a1HjAAkY
    attoparsec-0.14.4-HI028cZ2WwJ53VFJd3R6KF base-4.16.4.0
    bifunctors-5.6-IA0eoCGxXjELTsSzOWOQl4 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
    constraints-0.13.4-76OgJekagHZAdCWZy2IAJL containers-0.6.5.1
    deepseq-1.4.6.1 http-api-data-0.5.1-HKg2qwg5Pr62576hvuyzCI
    http-media-0.8.1.1-B56kqK3TszbF42ccT4k7kA
    http-types-0.12.4-K1BiuBnIehk6RPUQXWJDEB
    mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi mtl-2.2.2
    network-uri-2.6.4.2-BC3te0GfpncIdQCU8I2AdS
    singleton-bool-0.1.7-1uubXFtCW7Z2sKJGUSh2pN
    sop-core-0.5.0.2-LphaeyqHso5CwMqI1CLIch text-1.2.5.0
    transformers-0.5.6.2 vault-0.3.1.5-2WwncNHGOGpKNJyXR3fKcV

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
